@@ -18,11 +18,11 @@ URI::NamespaceMap - Class holding a collection of namespaces
 
 =head1 VERSION
 
-Version 0.24
+Version 0.26
 
 =cut
 
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 
 =head1 SYNOPSIS
@@ -49,10 +49,10 @@ This module provides an object to manage multiple namespaces for creating L<URI:
 Returns a new namespace map object. You can pass a hash reference with
 mappings from local names to namespace URIs (given as string or
 L<RDF::Trine::Node::Resource>) or namespaces_map with a hashref. You
-may also pass an arrayref containing just prefixes and/or namespace URIs,
-and the module will try to guess the missing part. To use this
-feature, you need L<RDF::NS>, L<XML::CommonNS> or L<RDF::Prefixes>, or
-preferably all of them.
+may also pass an arrayref containing just prefixes and/or namespace
+URIs, and the module will try to guess the missing part. To use this
+feature, you need L<RDF::NS::Curated>, L<RDF::NS>, L<XML::CommonNS> or
+L<RDF::Prefixes>, or preferably all of them.
 
 
 =item C<< add_mapping ( $name => $uri ) >>
@@ -249,19 +249,24 @@ sub AUTOLOAD {
 
 sub _guess {
 	my ($self, @data) = @_;
+	my $rnscu = can_load( modules => { 'RDF::NS::Curated' => 0 } );
 	my $xmlns = can_load( modules => { 'XML::CommonNS' => 0 } );
 	my $rdfns = can_load( modules => { 'RDF::NS' => 20130802 } );
 	my $rdfpr = can_load( modules => { 'RDF::Prefixes' => 0 } );
 	
-	confess 'To resolve an array, you need either XML::CommonNS, RDF::NS or RDF::Prefixes' unless ($xmlns || $rdfns || $rdfpr);
+	confess 'To resolve an array, you need either XML::CommonNS, RDF::NS or RDF::Prefixes' unless ($rnscu || $xmlns || $rdfns || $rdfpr);
 	my %namespaces;
 	
 	foreach my $entry (@data) {
 		
 		if ($entry =~ m/^[a-z]\w+$/i) {
 			# This is a prefix
-			warn "Cannot resolve '$entry' without XML::CommonNS or RDF::NS" unless ($xmlns || $rdfns);
-			if ($xmlns) {
+			warn "Cannot resolve '$entry' without RDF::NS::Curated, XML::CommonNS, RDF::NS" unless ($rnscu || $xmlns || $rdfns);
+			if ($rnscu) {
+				my $ns = RDF::NS::Curated->new;
+				$namespaces{$entry} = $ns->uri($entry);
+			}
+			if ((! $namespaces{$entry}) && $xmlns) {
 				require XML::CommonNS;
 				XML::CommonNS->import(':all');
 				try {
@@ -275,9 +280,13 @@ sub _guess {
 			warn "Cannot resolve '$entry'" unless $namespaces{$entry};
 		} else {
 			# Lets assume a URI string
-			warn "Cannot resolve '$entry' without RDF::NS or RDF::Prefixes" unless ($rdfns || $rdfpr);
+			warn "Cannot resolve '$entry' without RDF::NS::Curated, RDF::NS or RDF::Prefixes" unless ($rnscu || $rdfns || $rdfpr);
 			my $prefix;
-			if ($rdfns) {
+			if ($rnscu) {
+				my $ns = RDF::NS::Curated->new;
+				$prefix = $ns->prefix($entry);
+			}
+			if ((! $prefix) && ($rdfns)) {
 				my $ns = RDF::NS->new;
 				$prefix = $ns->PREFIX($entry);
 			}
